Revision history
================

0.1.4 2015-12-04

- Add Django 1.9 compatibility


0.1.3 2015-11-30

- Require Python 2.7+/3.2+
- Add slides from Django SF Meetup lightning talk


0.1.2 2015-06-14

- Add Django 1.8 compatibility


0.1.1 2015-06-11

- Rename ``taggit_count`` to ``taggit_counter``


0.1.0 2015-06-10

- Django admin helper classes for django-taggit tags

  - ``TaggitCounter``
  - ``TaggitListFilter``
  - ``TaggitStackedInline``
  - ``TaggitTabularInline``
